@@ -78,6 +78,20 @@ function _disconnect(id) {
     throw new Error("No signal connection " + id + " found");
 }
 
+function _signalHandlerIsConnected(id) {
+    if (!('_signalConnections' in this))
+        return false;
+
+    const {length} = this._signalConnections;
+    for (let i = 0; i < length; ++i) {
+        const connection = this._signalConnections[i];
+        if (connection.id === id)
+            return !connection.disconnected;
+    }
+
+    return false;
+}
+
 function _disconnectAll() {
     if ('_signalConnections' in this) {
         while (this._signalConnections.length > 0) {
@@ -86,7 +100,7 @@ function _disconnectAll() {
     }
 }
 
-function _emit(name /* , arg1, arg2 */) {
+function _emit(name, ...args) {
     // may not be any signal handlers at all, if not then return
     if (!('_signalConnections' in this))
         return;
@@ -111,13 +125,7 @@ function _emit(name /* , arg1, arg2 */) {
     // which does pass it in. Also if we pass in the emitter here,
     // people don't create closures with the emitter in them,
     // which would be a cycle.
-
-    let arg_array = [ this ];
-    // arguments[0] should be signal name so skip it
-    length = arguments.length;
-    for (i = 1; i < length; ++i) {
-        arg_array.push(arguments[i]);
-    }
+    let arg_array = [ this, ...args ];
 
     length = handlers.length;
     for (i = 0; i < length; ++i) {
@@ -154,6 +162,7 @@ function addSignalMethods(proto) {
     _addSignalMethod(proto, "connect", _connect);
     _addSignalMethod(proto, "disconnect", _disconnect);
     _addSignalMethod(proto, "emit", _emit);
+    _addSignalMethod(proto, 'signalHandlerIsConnected', _signalHandlerIsConnected);
     // this one is not in GObject, but useful
     _addSignalMethod(proto, "disconnectAll", _disconnectAll);
 }
@@ -163,5 +172,6 @@ var WithSignals = new Lang.Interface({
     connect: _connect,
     disconnect: _disconnect,
     emit: _emit,
+    signalHandlerIsConnected: _signalHandlerIsConnected,
     disconnectAll: _disconnectAll,
 });
